% Matlab script to default HPC cluster
% Part of UMD Matlab-Slurm integration scripts
% 
% Tries to see if we can default the HPC cluster from the hostname
% of the system we are running on.
%
% Author: Tom Payerle (payerle@umd.edu) 
% (c) University of Maryland 2022-2023
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file is part of the git repo 
% git@gitlab.umd.edu:acigs-enduser-sw/umd-slurm-matlab-scripts.git
% Please make any and all modifications there
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function defcluster = UmdDefaultClusterName()
% Try to default the HPC cluster name
%
% First try to default based on hostname of host running on.
% Otherwise, do a generic default.
%
% Returns the defaulted cluster name or [] if unable to default.

    defcluster = [];
    genericDefaultCluster = "zaratan";

    % Try to default based on hostname of system we are running on
    myHostname = getenv('HOSTNAME');
    if ~isempty(myHostname)
       tmplist = split(myHostname, '.');
       tmpLen = length(tmplist);
       if tmpLen > 2
           if tmplist(tmpLen) == "edu" && tmplist(tmpLen-1) == "umd"
               tmp = string(tmplist(tmpLen-2));

	       tmpinfo = UmdHpcClusterInfo(tmp, true);
	       if ~isempty(tmpinfo)
                   defcluster = tmp;
	       end
           end   
       end
    end

    if isempty(defcluster)
        defcluster = genericDefaultCluster;
    end
end
