% Matlab script to parse arguments for configClusterCommon
% Part of UMD Matlab-Slurm integration scripts
% 
% Author: Tom Payerle (payerle@umd.edu) 
% (c) University of Maryland 2022-2023
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file is part of the git repo 
% git@gitlab.umd.edu:acigs-enduser-sw/umd-slurm-matlab-scripts.git
% Please make any and all modifications there
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function val = configClusterArgumentQuery(Args)
    % Function to process arguments for configClusterCommon
    % 
    arguments
        % Value of argument passed to configClusterCommon
	Args.passed = []
        % interactive: logical, if not set, then will not prompt
	% user for values
	Args.interactive (1,1) logical = true
	% Prompt to use when asking user for information
	Args.prompt char = []
	% default value
	Args.defaultValue
	% type: type of value.  If we prompted for an answer from the
	% user, we will convert the answer given (if any) to this
	% type: char, string, or number.  Not used on passed or defaultValue
	Args.type char = 'string';
    end

    % Get cluster information
    passed = Args.passed;
    interactive = Args.interactive;
    rawPrompt = Args.prompt;
    haveDefault = isfield(Args, 'defaultValue');
    if haveDefault
        % We were given a default value, get it
        defaultValue = Args.defaultValue;
    end
    type = Args.type;

    % Ensure prompt is given if interactive set
    if interactive && isempty(rawPrompt)
        error('configClusterArgumentQuery:missingParm', ...
	    'prompt is required when interactive is set');
    end

    % Add the defaultValue to prompt if given
    prompt = rawPrompt;
    if interactive
	if haveDefault
           prompt = sprintf('%s: [%s] ', prompt, string(defaultValue));
        else
           prompt = sprintf('%s: ', prompt);
	end
    end
    
    val = passed;
    if isempty(val) && interactive
        % No value passed to configClusterCommon, but interactive set
	% so ask the user
        val = input(prompt, 's');
        % Convert result to desired type if we have a val
        if ~isempty(val)
            switch type
                case { 'string' }
	            val = string(val);
                case { 'char' }
	            val = char(val);
                case { 'number', 'numeric' }
	            val = str2num(val);
	    otherwise
                error("configClusterArgumentQuery:badValue", ...
	            "Illegal value [%s] for type; expecting one of " + ...
		    "string, char, or number", type);
            end %switch
	end %if ~isempty(val)
    end %if ~isempty(val)

    if isempty(val) && haveDefault
        % No value passed, and/or no value or default given
	val = defaultValue;
    end

end
